
#!/usr/bin/env python
# coding: utf-8

from setuptools import setup


#rn()
print(111)

setup(
    name='sankuai',
    version='4.1', # 项�~[��~I~H�~\� 
    author='xingxing', # 项�~[��~\�~@~E 
    author_email='duxinglin123@gmail.com', # �~\�~@~Eemail 
    url='https://github.com/', # 项�~[�代�| ~A�~S�~S
    description='hello word', # 项�~[��~O~O述 
    #packages=['portal-api'], # �~L~E�~P~M 
    install_requires=[],
        classifiers          = [
        'Topic :: Security',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
        'Intended Audience :: Developers'
    ]
)
